%bcond_without tests

Summary:        A fast multidimensional array facility for Python
Name:           numpy
Version:        1.25.2
Release:        4%{?dist}
License:        BSD and Python and ASL 2.0
URL:            http://www.numpy.org/
Source0:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz

%description
NumPy is an open source project aiming to enable numerical computing with Python.
It builds on the early work of the Numeric and Numarray libraries.

%package -n     python3-numpy
Summary:        A fast multidimensional array facility for Python
License:        BSD
BuildRequires:  python3-devel flexiblas-devel lapack-devel
BuildRequires:  python3-setuptools python3-Cython
BuildRequires:  gcc-gfortran gcc gcc-c++
%if %{with tests}
BuildRequires:  python3-hypothesis python3-pytest python3-test
%endif

Provides:       numpy = %{version}-%{release}
Provides:       python-numpy = %{version}-%{release}
Provides:       python%{python3_version}-numpy = %{version}-%{release}
Provides:       libnpymath-static = %{version}-%{release}

%description -n python3-numpy
 It is a Python library that provides a multidimensional array object,
various derived objects (such as masked arrays and matrices), and an
assortment of routines for fast operations on arrays, including mathematical,
logical, shape manipulation, sorting, selecting, I/O, discrete Fourier
transforms, basic linear algebra, basic statistical operations,
random simulation and much more.

%package -n     python3-numpy-f2py
Summary:        f2py for numpy
Requires:       python3-numpy = %{version}-%{release}
Requires:       python3-devel
Provides:       python3-f2py = %{version}-%{release}
Provides:       python-numpy-f2py = %{version}-%{release}
Provides:       python%{python3_version}-f2py = %{version}-%{release}
Provides:       f2py = %{version}-%{release}
Provides:       numpy-f2py = %{version}-%{release}

%description -n python3-numpy-f2py
This package includes a version of f2py that works properly with NumPy.

%prep
%autosetup -n %{name}-%{version} -p1

rm PKG-INFO
cat >> site.cfg <<EOF
[openblas]
libraries = flexiblas
library_dirs = %{_libdir}
EOF
 
%build
env OPENBLAS=%{_libdir} \
    BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags}" 
    %{__python3} setup.py build

%install
env OPENBLAS=%{_libdir} \
    FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags}" 
    %{__python3} setup.py install --root %{buildroot}
pushd %{buildroot}%{_bindir} &> /dev/null
ln -s f2py3 f2py.numpy
popd &> /dev/null

mkdir -p %{buildroot}%{_includedir}
ln -s %{python3_sitearch}/%{name}/core/include/numpy/ %{buildroot}%{_includedir}/numpy

%check
%if %{with tests}
export SETUPTOOLS_USE_DISTUTILS=stdlib
export PYTHONPATH=%{buildroot}%{python3_sitearch}
%ifarch ppc64le
%global extra_test_option and not test_einsum_sums_cfloat64
%endif
%ifarch aarch64
%global extra_test_option and not test_cpu_features
%endif

python3 runtests.py  --no-build -- -ra -k 'not test_ppc64_ibm_double_double128 %{?extra_test_option}'
%endif


%files -n python3-numpy
%license LICENSE.txt
%doc THANKS.txt site.cfg.example
%{python3_sitearch}/%{name}/__pycache__
%dir %{python3_sitearch}/%{name}
%{python3_sitearch}/%{name}/*.py*
%{python3_sitearch}/%{name}/core
%{python3_sitearch}/%{name}/distutils
%{python3_sitearch}/%{name}/doc
%{python3_sitearch}/%{name}/fft
%{python3_sitearch}/%{name}/lib
%{python3_sitearch}/%{name}/linalg
%{python3_sitearch}/%{name}/ma
%{python3_sitearch}/%{name}/random
%{python3_sitearch}/%{name}/testing
%{python3_sitearch}/%{name}/tests
%{python3_sitearch}/%{name}/compat
%{python3_sitearch}/%{name}/matrixlib
%{python3_sitearch}/%{name}/polynomial
%{python3_sitearch}/%{name}-*.egg-info
%exclude %{python3_sitearch}/%{name}/LICENSE.txt
%{python3_sitearch}/%{name}/__init__.pxd
%{python3_sitearch}/%{name}/__init__.cython-30.pxd
%{python3_sitearch}/%{name}/py.typed
%{python3_sitearch}/%{name}/typing/
%{python3_sitearch}/%{name}/array_api/
%{python3_sitearch}/%{name}/_pyinstaller/
%{python3_sitearch}/%{name}/_typing/
%{python3_sitearch}/%{name}/_utils/
%{_includedir}/numpy

%files -n python3-numpy-f2py
%{_bindir}/f2py
%{_bindir}/f2py3
%{_bindir}/f2py.numpy
%{_bindir}/f2py%{python3_version}
%{python3_sitearch}/%{name}/f2py

%changelog
* Tue Jun 4 2024 Shuo Wang <abushwang@tencent.com> - 1.25.2-4
- enable %check

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.25.2-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.25.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 29 2023 Shuo Wang <abushwang@tencent.com> - 1.25.2-1
- update to 1.25.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22.0-6
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.22.0-5
- Rebuilt for OpenCloudOS Stream 23

* Tue Feb 21 2023 Shuo Wang <abushwang@tencent.com> - 1.22.0-4
- remove unused buildrequires

* Thu Jan 5 2023 Zhao Zhen <jeremiazhao@tencent.com> - 1.22.0-3
- disabled cpu feature tests on arm64

* Mon Oct 10 2022 Wang Guodong <gordonwwang@tencent.com> - 1.22.0-2
- Set the environment variable(SETUPTOOLS_USE_DISTUTILS) to solve 
  setuptools-bundled distutils' LooseVersion issue.

* Fri Sep 9 2022 Shuo Wang <abushwang@tencent.com> - 1.22.0-1
- initial build
